package mygame;

import org.newdawn.slick.AppGameContainer;
import org.newdawn.slick.BasicGame;
import org.newdawn.slick.Color;
import org.newdawn.slick.GameContainer;
import org.newdawn.slick.Graphics;
import org.newdawn.slick.Image;
import org.newdawn.slick.Input;
import org.newdawn.slick.SlickException;

/**
敵機を登場させてみる。
@author フラチキさん
*/
public class MyGame06 extends BasicGame {
	// 自機スプライトの画像
	Image my_sprite;

	// 自機の座標
	int my_x = 240;
	int my_y = 500;

	// 自機の移動速度
	int my_speed = 10;

	// 弾丸スプライトの画像
	Image bullet_sprite;

	// 同時に発射できる弾丸の最大数
	int max_bullets = 10;

	// 弾丸の発射フラグ
	boolean[] bullet_fired = new boolean [max_bullets];

	// 弾丸の座標
	int[] bullet_x = new int [max_bullets];
	int[] bullet_y = new int [max_bullets];

	// 弾丸の移動速度
	int bullet_speed = 30;

	// 次に弾丸を発射できるようになるまでのウェイト(連射速度の制御)
	int bullet_wait;

	/**
	コンストラクタ
	*/
	public MyGame06() {
		super("MyGame06");
	}

	/**
	最初に一回だけ実行される初期化。
	*/
	public void init(GameContainer container) throws SlickException {
		container.getGraphics().setBackground(new Color(0.4f,0.6f,0.6f));

		// ファイルからスプライト画像を読み込む。
		my_sprite = new Image("mygame/f15.png");
		bullet_sprite = new Image("mygame/gun.png");
	}

	/**
	毎フレーム実行される描画。
	*/
	public void render(GameContainer container, Graphics g) {
		// 自機スプライトを表示する。
		my_sprite.draw(my_x, my_y);

		// 弾丸スプライトを描画する。
		// 配列から発射されている弾丸を探して描画する。
		for (int i = 0; i < max_bullets; i++) {
			if (bullet_fired[i]) {
				bullet_sprite.draw(bullet_x[i], bullet_y[i]);
			}
		}
	}

	/**
	毎フレーム実行される更新。
	*/
	public void update(GameContainer container, int delta) {
		// プレイヤー機の移動
		Input input = container.getInput();
		if (input.isKeyDown(Input.KEY_LEFT))  my_x = my_x - my_speed;
		if (input.isKeyDown(Input.KEY_RIGHT)) my_x = my_x + my_speed;
		if (input.isKeyDown(Input.KEY_UP))    my_y = my_y - my_speed;
		if (input.isKeyDown(Input.KEY_DOWN))  my_y = my_y + my_speed;

		// プレイヤー機の移動範囲を制限
		int limit_x = (480 - my_sprite.getWidth());  // 画面右端の座標
		int limit_y = (640 - my_sprite.getHeight());  // 画面下端の座標
		if(my_x < 0)       my_x = 0;
		if(limit_x < my_x) my_x = limit_x;
		if(my_y < 0)       my_y = 0;
		if(limit_y < my_y) my_y = limit_y;

		// 弾丸移動
		// 配列から発射されている弾丸を探して移動する。
		for (int i = 0; i < max_bullets; i++) {
			if (bullet_fired[i]) {
				bullet_y[i] = bullet_y[i] - bullet_speed;
				if(bullet_y[i] < 0) bullet_fired[i] = false;
			}
		}

		// 弾丸発射
		// 先回弾丸を発射してから決められた時間が経過していたら次の弾丸を発射できる。
		if (bullet_wait == 0) {
			if (input.isKeyDown(Input.KEY_SPACE)) {
				// 弾丸配列の空いている場所を探してそこの変数を使う。
				for (int i = 0; i < max_bullets; i++) {
					if (bullet_fired[i] == false) {
						bullet_fired[i] = true;
						bullet_x[i] = my_x + my_sprite.getWidth()/2;
						bullet_y[i] = my_y;
						// 次の弾丸を発射できるまで5フレーム待つように設定。
						bullet_wait = 5;
						break;
					}
				}
			}
		} else {
			// 弾丸の発射待ちだったらカウントダウンする。
			bullet_wait--;
		}
	}

	/**
	プログラムはここから実行される。
	@param argv プログラムの起動時に渡されたコマンドライン引数。
	*/
	public static void main(String[] argv) {
		try {
			AppGameContainer container = new AppGameContainer(new MyGame06());
			container.setDisplayMode(480,640,false);
			container.setTargetFrameRate(60);
			container.start();
		} catch (SlickException e) {
			e.printStackTrace();
		}
	}
}
